# Metron.cloud plugin for Comic Tagger

A plugin for [Comic Tagger](https://github.com/comictagger/comictagger/releases) to allow the use of the metadata from [Metron.cloud](https://metron.cloud/).

## Work in progress

The 'master' branch aims to be up-to-date with comictagger 'develop' branch

Some options will cause longer processing times, check help messages.

## Install

`pip install .`
